#ifndef _LRT_H_
#define _LRT_H_
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 Likelihood ratio test   R O U T I N E S 
 
 moved out from world.c                                                                                                               
 Peter Beerli 2000, Seattle
 beerli@csit.fsu.edu
 
Copyright 2001 Peter Beerli and Joseph Felsenstein
 
$Id: lrt.h,v 1.7 2003/11/04 16:12:08 beerli Exp $
-------------------------------------------------------*/

extern void print_lratio_test (world_fmt * world, long *Gmax);
extern void lrt_connect (char *thisString, char *connect2, world_fmt *world);

#endif
